@@ -7,9 +7,9 @@
 #include "UpdateModel.h"
 
 // Qt includes
+#include "libdiscover_debug.h"
 #include <QFont>
 #include <QTimer>
-#include "libdiscover_debug.h"
 
 // KDE includes
 #include <KFormat>
@@ -18,8 +18,8 @@
 // Own includes
 #include "UpdateItem.h"
 #include <resources/AbstractResource.h>
-#include <resources/ResourcesUpdatesModel.h>
 #include <resources/ResourcesModel.h>
+#include <resources/ResourcesUpdatesModel.h>
 
 UpdateModel::UpdateModel(QObject *parent)
     : QAbstractListModel(parent)
@@ -42,7 +42,7 @@ UpdateModel::~UpdateModel()
     m_updateItems.clear();
 }
 
-QHash<int,QByteArray> UpdateModel::roleNames() const
+QHash<int, QByteArray> UpdateModel::roleNames() const
 {
     auto ret = QAbstractItemModel::roleNames();
     ret.insert(Qt::CheckStateRole, "checked");
@@ -56,7 +56,7 @@ QHash<int,QByteArray> UpdateModel::roleNames() const
     return ret;
 }
 
-void UpdateModel::setBackend(ResourcesUpdatesModel* updates)
+void UpdateModel::setBackend(ResourcesUpdatesModel *updates)
 {
     if (m_updates) {
         disconnect(m_updates, nullptr, this, nullptr);
@@ -70,16 +70,16 @@ void UpdateModel::setBackend(ResourcesUpdatesModel* updates)
     activityChanged();
 }
 
-void UpdateModel::resourceHasProgressed(AbstractResource* res, qreal progress, AbstractBackendUpdater::State state)
+void UpdateModel::resourceHasProgressed(AbstractResource *res, qreal progress, AbstractBackendUpdater::State state)
 {
-    UpdateItem* item = itemFromResource(res);
+    UpdateItem *item = itemFromResource(res);
     if (!item)
         return;
     item->setProgress(progress);
     item->setState(state);
 
     const QModelIndex idx = indexFromItem(item);
-    Q_EMIT dataChanged(idx, idx, { ResourceProgressRole, ResourceStateRole, SectionResourceProgressRole });
+    Q_EMIT dataChanged(idx, idx, {ResourceProgressRole, ResourceStateRole, SectionResourceProgressRole});
 }
 
 void UpdateModel::activityChanged()
@@ -89,7 +89,7 @@ void UpdateModel::activityChanged()
             m_updates->prepare();
             setResources(m_updates->toUpdate());
 
-            for(auto item : qAsConst(m_updateItems)) {
+            for (auto item : qAsConst(m_updateItems)) {
                 item->setProgress(0);
             }
         } else
@@ -115,7 +115,7 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
     case SizeRole:
         return KFormat().formatByteSize(item->size());
     case ResourceRole:
-        return QVariant::fromValue<QObject*>(item->resource());
+        return QVariant::fromValue<QObject *>(item->resource());
     case ResourceProgressRole:
         return item->progress();
     case ResourceStateRole:
@@ -126,15 +126,18 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
         static const QString appUpdatesSection = i18nc("@item:inlistbox", "Application Updates");
         static const QString systemUpdateSection = i18nc("@item:inlistbox", "System Updates");
         static const QString addonsSection = i18nc("@item:inlistbox", "Addons");
-        switch(item->resource()->type()) {
-            case AbstractResource::Application: return appUpdatesSection;
-            case AbstractResource::Technical: return systemUpdateSection;
-            case AbstractResource::Addon: return addonsSection;
+        switch (item->resource()->type()) {
+        case AbstractResource::Application:
+            return appUpdatesSection;
+        case AbstractResource::Technical:
+            return systemUpdateSection;
+        case AbstractResource::Addon:
+            return addonsSection;
         }
         Q_UNREACHABLE();
     }
     case SectionResourceProgressRole:
-        return (100-item->progress()) + (101 * item->resource()->type());
+        return (100 - item->progress()) + (101 * item->resource()->type());
     default:
         break;
     }
@@ -142,9 +145,9 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
     return QVariant();
 }
 
-void UpdateModel::checkResources(const QList<AbstractResource*>& resource, bool checked)
+void UpdateModel::checkResources(const QList<AbstractResource *> &resource, bool checked)
 {
-    if(checked)
+    if (checked)
         m_updates->addResources(resource);
     else
         m_updates->removeResources(resource);
@@ -168,14 +171,14 @@ bool UpdateModel::setData(const QModelIndex &idx, const QVariant &value, int rol
     if (role == Qt::CheckStateRole) {
         UpdateItem *item = itemFromIndex(idx);
         const bool newValue = value.toInt() == Qt::Checked;
-        const QList<AbstractResource *> apps = { item->app() };
+        const QList<AbstractResource *> apps = {item->app()};
 
         checkResources(apps, newValue);
         Q_ASSERT(idx.data(Qt::CheckStateRole) == value);
 
-        //When un/checking some backends will decide to add or remove a bunch of packages, so refresh it all
+        // When un/checking some backends will decide to add or remove a bunch of packages, so refresh it all
         auto m = idx.model();
-        Q_EMIT dataChanged(m->index(0, 0), m->index(m->rowCount()-1, 0), { Qt::CheckStateRole });
+        Q_EMIT dataChanged(m->index(0, 0), m->index(m->rowCount() - 1, 0), {Qt::CheckStateRole});
         Q_EMIT toUpdateChanged();
 
         return true;
@@ -188,14 +191,15 @@ void UpdateModel::fetchUpdateDetails(int row)
 {
     UpdateItem *item = itemFromIndex(index(row, 0));
     Q_ASSERT(item);
-    if (!item) return;
+    if (!item)
+        return;
 
     item->app()->fetchUpdateDetails();
 }
 
 void UpdateModel::integrateChangelog(const QString &changelog)
 {
-    auto app = qobject_cast<AbstractResource*>(sender());
+    auto app = qobject_cast<AbstractResource *>(sender());
     Q_ASSERT(app);
     auto item = itemFromResource(app);
     if (!item)
@@ -205,10 +209,10 @@ void UpdateModel::integrateChangelog(const QString &changelog)
 
     const QModelIndex idx = indexFromItem(item);
     Q_ASSERT(idx.isValid());
-    emit dataChanged(idx, idx, { ChangelogRole });
+    Q_EMIT dataChanged(idx, idx, {ChangelogRole});
 }
 
-void UpdateModel::setResources(const QList<AbstractResource*>& resources)
+void UpdateModel::setResources(const QList<AbstractResource *> &resources)
 {
     if (resources == m_resources) {
         return;
@@ -219,29 +223,31 @@ void UpdateModel::setResources(const QList<AbstractResource*>& resources)
     qDeleteAll(m_updateItems);
     m_updateItems.clear();
 
-    QVector<UpdateItem*> appItems, systemItems, addonItems;
-    foreach(AbstractResource* res, resources) {
+    QVector<UpdateItem *> appItems, systemItems, addonItems;
+    foreach (AbstractResource *res, resources) {
         connect(res, &AbstractResource::changelogFetched, this, &UpdateModel::integrateChangelog, Qt::UniqueConnection);
 
         UpdateItem *updateItem = new UpdateItem(res);
 
-        switch(res->type()) {
-            case AbstractResource::Technical:
-                systemItems += updateItem;
-                break;
-            case AbstractResource::Application:
-                appItems += updateItem;
-                break;
-            case AbstractResource::Addon:
-                addonItems += updateItem;
-                break;
+        switch (res->type()) {
+        case AbstractResource::Technical:
+            systemItems += updateItem;
+            break;
+        case AbstractResource::Application:
+            appItems += updateItem;
+            break;
+        case AbstractResource::Addon:
+            addonItems += updateItem;
+            break;
         }
     }
-    const auto sortUpdateItems = [](UpdateItem *a, UpdateItem *b) { return a->name() < b->name(); };
+    const auto sortUpdateItems = [](UpdateItem *a, UpdateItem *b) {
+        return a->name() < b->name();
+    };
     std::sort(appItems.begin(), appItems.end(), sortUpdateItems);
     std::sort(systemItems.begin(), systemItems.end(), sortUpdateItems);
     std::sort(addonItems.begin(), addonItems.end(), sortUpdateItems);
-    m_updateItems = (QVector<UpdateItem*>() << appItems << addonItems << systemItems);
+    m_updateItems = (QVector<UpdateItem *>() << appItems << addonItems << systemItems);
     endResetModel();
 
     Q_EMIT hasUpdatesChanged(!resources.isEmpty());
@@ -253,7 +259,7 @@ bool UpdateModel::hasUpdates() const
     return rowCount() > 0;
 }
 
-ResourcesUpdatesModel* UpdateModel::backend() const
+ResourcesUpdatesModel *UpdateModel::backend() const
 {
     return m_updates;
 }
@@ -262,7 +268,7 @@ int UpdateModel::toUpdateCount() const
 {
     int ret = 0;
     QSet<QString> packages;
-    foreach (UpdateItem* item, m_updateItems) {
+    foreach (UpdateItem *item, m_updateItems) {
         const auto packageName = item->resource()->packageName();
         if (packages.contains(packageName)) {
             continue;
@@ -277,7 +283,7 @@ int UpdateModel::totalUpdatesCount() const
 {
     int ret = 0;
     QSet<QString> packages;
-    foreach (UpdateItem* item, m_updateItems) {
+    foreach (UpdateItem *item, m_updateItems) {
         const auto packageName = item->resource()->packageName();
         if (packages.contains(packageName)) {
             continue;
@@ -288,9 +294,9 @@ int UpdateModel::totalUpdatesCount() const
     return ret;
 }
 
-UpdateItem * UpdateModel::itemFromResource(AbstractResource* res)
+UpdateItem *UpdateModel::itemFromResource(AbstractResource *res)
 {
-    foreach (UpdateItem* item, m_updateItems) {
+    foreach (UpdateItem *item, m_updateItems) {
         if (item->app() == res)
             return item;
     }
@@ -302,17 +308,17 @@ QString UpdateModel::updateSize() const
     return m_updates ? KFormat().formatByteSize(m_updates->updateSize()) : QString();
 }
 
-QModelIndex UpdateModel::indexFromItem(UpdateItem* item) const
+QModelIndex UpdateModel::indexFromItem(UpdateItem *item) const
 {
     return index(m_updateItems.indexOf(item), 0, {});
 }
 
-UpdateItem * UpdateModel::itemFromIndex(const QModelIndex& index) const
+UpdateItem *UpdateModel::itemFromIndex(const QModelIndex &index) const
 {
     return m_updateItems[index.row()];
 }
 
-void UpdateModel::resourceDataChanged(AbstractResource* res, const QVector<QByteArray>& properties)
+void UpdateModel::resourceDataChanged(AbstractResource *res, const QVector<QByteArray> &properties)
 {
     auto item = itemFromResource(res);
     if (!item)
@@ -329,14 +335,14 @@ void UpdateModel::resourceDataChanged(AbstractResource* res, const QVector<QByte
 
 void UpdateModel::checkAll()
 {
-    for(int i=0, c=rowCount(); i<c; ++i)
-        if(index(i,0).data(Qt::CheckStateRole) != Qt::Checked)
-            setData(index(i,0), Qt::Checked, Qt::CheckStateRole);
+    for (int i = 0, c = rowCount(); i < c; ++i)
+        if (index(i, 0).data(Qt::CheckStateRole) != Qt::Checked)
+            setData(index(i, 0), Qt::Checked, Qt::CheckStateRole);
 }
 
 void UpdateModel::uncheckAll()
 {
-    for(int i=0, c=rowCount(); i<c; ++i)
-        if(index(i,0).data(Qt::CheckStateRole) != Qt::Unchecked)
-            setData(index(i,0), Qt::Unchecked, Qt::CheckStateRole);
+    for (int i = 0, c = rowCount(); i < c; ++i)
+        if (index(i, 0).data(Qt::CheckStateRole) != Qt::Unchecked)
+            setData(index(i, 0), Qt::Unchecked, Qt::CheckStateRole);
 }
