@@ -7,61 +7,72 @@
 #include "ResourcesModel.h"
 
 #include "AbstractResource.h"
-#include "resources/AbstractResourcesBackend.h"
-#include "resources/AbstractBackendUpdater.h"
-#include <ReviewsBackend/Rating.h>
-#include <ReviewsBackend/AbstractReviewsBackend.h>
-#include <Transaction/Transaction.h>
-#include <DiscoverBackendsFactory.h>
-#include "Transaction/TransactionModel.h"
 #include "Category/CategoryModel.h"
-#include "utils.h"
+#include "Transaction/TransactionModel.h"
 #include "libdiscover_debug.h"
-#include <functional>
-#include <QCoreApplication>
-#include <QThread>
-#include <QAction>
-#include <QMetaProperty>
+#include "resources/AbstractBackendUpdater.h"
+#include "resources/AbstractResourcesBackend.h"
+#include "utils.h"
+#include <DiscoverBackendsFactory.h>
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <KConfigGroup>
+#include <QCoreApplication>
+#include <QIcon>
+#include <QMetaProperty>
+#include <QThread>
+#include <ReviewsBackend/AbstractReviewsBackend.h>
+#include <ReviewsBackend/Rating.h>
+#include <Transaction/Transaction.h>
+#include <functional>
+#include <resources/DiscoverAction.h>
 
 ResourcesModel *ResourcesModel::s_self = nullptr;
 
 ResourcesModel *ResourcesModel::global()
 {
-    if(!s_self)
+    if (!s_self)
         s_self = new ResourcesModel;
     return s_self;
 }
 
-ResourcesModel::ResourcesModel(QObject* parent, bool load)
+ResourcesModel::ResourcesModel(QObject *parent, bool load)
     : QObject(parent)
     , m_isFetching(false)
     , m_initializingBackends(0)
     , m_currentApplicationBackend(nullptr)
     , m_allInitializedEmitter(new QTimer(this))
-    , m_updatesCount(0, [this] {
-        {
-            int ret = 0;
-            foreach(AbstractResourcesBackend* backend, m_backends) {
-                ret += backend->updatesCount();
-            }
-            return ret;
-        }
-    }, [this](int count){ Q_EMIT updatesCountChanged(count); })
-    , m_fetchingUpdatesProgress(0, [this] {
-        {
-            if (m_backends.isEmpty())
-                return 0;
+    , m_updatesCount(
+          0,
+          [this] {
+              {
+                  int ret = 0;
+                  foreach (AbstractResourcesBackend *backend, m_backends) {
+                      ret += backend->updatesCount();
+                  }
+                  return ret;
+              }
+          },
+          [this](int count) {
+              Q_EMIT updatesCountChanged(count);
+          })
+    , m_fetchingUpdatesProgress(
+          0,
+          [this] {
+              {
+                  if (m_backends.isEmpty())
+                      return 0;
 
-            int sum = 0;
-            for(auto backend: qAsConst(m_backends)) {
-                sum += backend->fetchingUpdatesProgress();
-            }
-            return sum / m_backends.count();
-        }
-    }, [this](int progress){ Q_EMIT fetchingUpdatesProgressChanged(progress); })
+                  int sum = 0;
+                  for (auto backend : qAsConst(m_backends)) {
+                      sum += backend->fetchingUpdatesProgress();
+                  }
+                  return sum / m_backends.count();
+              }
+          },
+          [this](int progress) {
+              Q_EMIT fetchingUpdatesProgressChanged(progress);
+          })
 {
     init(load);
     connect(this, &ResourcesModel::allInitialized, this, &ResourcesModel::slotFetching);
@@ -71,33 +82,31 @@ ResourcesModel::ResourcesModel(QObject* parent, bool load)
 void ResourcesModel::init(bool load)
 {
     Q_ASSERT(!s_self);
-    Q_ASSERT(QCoreApplication::instance()->thread()==QThread::currentThread());
+    Q_ASSERT(QCoreApplication::instance()->thread() == QThread::currentThread());
 
     m_allInitializedEmitter->setSingleShot(true);
     m_allInitializedEmitter->setInterval(0);
-    connect(m_allInitializedEmitter, &QTimer::timeout, this, [this](){
+    connect(m_allInitializedEmitter, &QTimer::timeout, this, [this]() {
         if (m_initializingBackends == 0)
-            emit allInitialized();
+            Q_EMIT allInitialized();
     });
 
-    if(load)
+    if (load)
         QMetaObject::invokeMethod(this, "registerAllBackends", Qt::QueuedConnection);
 
-
-    m_updateAction = new QAction(this);
+    m_updateAction = new DiscoverAction(this);
     m_updateAction->setIcon(QIcon::fromTheme(QStringLiteral("system-software-update")));
     m_updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
-    m_updateAction->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_R));
     connect(this, &ResourcesModel::fetchingChanged, m_updateAction, [this](bool fetching) {
         m_updateAction->setEnabled(!fetching);
         m_fetchingUpdatesProgress.reevaluate();
     });
-    connect(m_updateAction, &QAction::triggered, this, &ResourcesModel::checkForUpdates);
+    connect(m_updateAction, &DiscoverAction::triggered, this, &ResourcesModel::checkForUpdates);
 
     connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, this, &QObject::deleteLater);
 }
 
-ResourcesModel::ResourcesModel(const QString& backendName, QObject* parent)
+ResourcesModel::ResourcesModel(const QString &backendName, QObject *parent)
     : ResourcesModel(parent, false)
 {
     s_self = this;
@@ -110,10 +119,10 @@ ResourcesModel::~ResourcesModel()
     qDeleteAll(m_backends);
 }
 
-void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
+void ResourcesModel::addResourcesBackend(AbstractResourcesBackend *backend)
 {
     Q_ASSERT(!m_backends.contains(backend));
-    if(!backend->isValid()) {
+    if (!backend->isValid()) {
         qCWarning(LIBDISCOVER_LOG) << "Discarding invalid backend" << backend->name();
         CategoryModel::global()->blacklistPlugin(backend->name());
         backend->deleteLater();
@@ -121,7 +130,7 @@ void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
     }
 
     m_backends += backend;
-    if(!backend->isFetching()) {
+    if (!backend->isFetching()) {
         m_updatesCount.reevaluate();
     } else {
         m_initializingBackends++;
@@ -130,8 +139,12 @@ void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
     connect(backend, &AbstractResourcesBackend::fetchingChanged, this, &ResourcesModel::callerFetchingChanged);
     connect(backend, &AbstractResourcesBackend::allDataChanged, this, &ResourcesModel::updateCaller);
     connect(backend, &AbstractResourcesBackend::resourcesChanged, this, &ResourcesModel::resourceDataChanged);
-    connect(backend, &AbstractResourcesBackend::updatesCountChanged, this, [this] { m_updatesCount.reevaluate(); });
-    connect(backend, &AbstractResourcesBackend::fetchingUpdatesProgressChanged, this, [this] { m_fetchingUpdatesProgress.reevaluate(); });
+    connect(backend, &AbstractResourcesBackend::updatesCountChanged, this, [this] {
+        m_updatesCount.reevaluate();
+    });
+    connect(backend, &AbstractResourcesBackend::fetchingUpdatesProgressChanged, this, [this] {
+        m_fetchingUpdatesProgress.reevaluate();
+    });
     connect(backend, &AbstractResourcesBackend::resourceRemoved, this, &ResourcesModel::resourceRemoved);
     connect(backend, &AbstractResourcesBackend::passiveMessage, this, &ResourcesModel::passiveMessage);
     connect(backend->backendUpdater(), &AbstractBackendUpdater::progressingChanged, this, &ResourcesModel::slotFetching);
@@ -143,7 +156,7 @@ void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
     // pre-filled, we still need for the rest of the backends to be added before trying
     // to send out the initialized signal. To ensure this happens, schedule it for the
     // start of the next run of the event loop.
-    if(m_initializingBackends==0) {
+    if (m_initializingBackends == 0) {
         m_allInitializedEmitter->start();
     } else {
         slotFetching();
@@ -152,12 +165,12 @@ void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
 
 void ResourcesModel::callerFetchingChanged()
 {
-    AbstractResourcesBackend* backend = qobject_cast<AbstractResourcesBackend*>(sender());
+    AbstractResourcesBackend *backend = qobject_cast<AbstractResourcesBackend *>(sender());
 
     if (!backend->isValid()) {
         qCWarning(LIBDISCOVER_LOG) << "Discarding invalid backend" << backend->name();
         int idx = m_backends.indexOf(backend);
-        Q_ASSERT(idx>=0);
+        Q_ASSERT(idx >= 0);
         m_backends.removeAt(idx);
         Q_EMIT backendsChanged();
         CategoryModel::global()->blacklistPlugin(backend->name());
@@ -166,26 +179,26 @@ void ResourcesModel::callerFetchingChanged()
         return;
     }
 
-    if(backend->isFetching()) {
+    if (backend->isFetching()) {
         m_initializingBackends++;
         slotFetching();
     } else {
         m_initializingBackends--;
-        if(m_initializingBackends==0)
+        if (m_initializingBackends == 0)
             m_allInitializedEmitter->start();
         else
             slotFetching();
     }
 }
 
-void ResourcesModel::updateCaller(const QVector<QByteArray>& properties)
+void ResourcesModel::updateCaller(const QVector<QByteArray> &properties)
 {
-    AbstractResourcesBackend* backend = qobject_cast<AbstractResourcesBackend*>(sender());
-    
+    AbstractResourcesBackend *backend = qobject_cast<AbstractResourcesBackend *>(sender());
+
     Q_EMIT backendDataChanged(backend, properties);
 }
 
-QVector< AbstractResourcesBackend* > ResourcesModel::backends() const
+QVector<AbstractResourcesBackend *> ResourcesModel::backends() const
 {
     return m_backends;
 }
@@ -194,24 +207,24 @@ bool ResourcesModel::hasSecurityUpdates() const
 {
     bool ret = false;
 
-    foreach(AbstractResourcesBackend* backend, m_backends) {
+    foreach (AbstractResourcesBackend *backend, m_backends) {
         ret |= backend->hasSecurityUpdates();
     }
 
     return ret;
 }
 
-void ResourcesModel::installApplication(AbstractResource* app)
+void ResourcesModel::installApplication(AbstractResource *app)
 {
     TransactionModel::global()->addTransaction(app->backend()->installApplication(app));
 }
 
-void ResourcesModel::installApplication(AbstractResource* app, const AddonList& addons)
+void ResourcesModel::installApplication(AbstractResource *app, const AddonList &addons)
 {
     TransactionModel::global()->addTransaction(app->backend()->installApplication(app, addons));
 }
 
-void ResourcesModel::removeApplication(AbstractResource* app)
+void ResourcesModel::removeApplication(AbstractResource *app)
 {
     TransactionModel::global()->addTransaction(app->backend()->removeApplication(app));
 }
@@ -220,25 +233,25 @@ void ResourcesModel::registerAllBackends()
 {
     DiscoverBackendsFactory f;
     const auto backends = f.allBackends();
-    if(m_initializingBackends==0 && backends.isEmpty()) {
+    if (m_initializingBackends == 0 && backends.isEmpty()) {
         qCWarning(LIBDISCOVER_LOG) << "Couldn't find any backends";
         m_allInitializedEmitter->start();
     } else {
-        foreach(AbstractResourcesBackend* b, backends) {
+        foreach (AbstractResourcesBackend *b, backends) {
             addResourcesBackend(b);
         }
-        emit backendsChanged();
+        Q_EMIT backendsChanged();
     }
 }
 
-void ResourcesModel::registerBackendByName(const QString& name)
+void ResourcesModel::registerBackendByName(const QString &name)
 {
     DiscoverBackendsFactory f;
     const auto backends = f.backend(name);
-    for(auto b : backends)
+    for (auto b : backends)
         addResourcesBackend(b);
 
-    emit backendsChanged();
+    Q_EMIT backendsChanged();
 }
 
 bool ResourcesModel::isFetching() const
@@ -249,12 +262,12 @@ bool ResourcesModel::isFetching() const
 void ResourcesModel::slotFetching()
 {
     bool newFetching = false;
-    foreach(AbstractResourcesBackend* b, m_backends) {
+    foreach (AbstractResourcesBackend *b, m_backends) {
         // isFetching should sort of be enough. However, sometimes the backend itself
         // will still be operating on things, which from a model point of view would
         // still mean something going on. So, interpret that as fetching as well, for
         // the purposes of this property.
-        if(b->isFetching() || (b->backendUpdater() && b->backendUpdater()->isProgressing())) {
+        if (b->isFetching() || (b->backendUpdater() && b->backendUpdater()->isProgressing())) {
             newFetching = true;
             break;
         }
@@ -270,10 +283,10 @@ bool ResourcesModel::isBusy() const
     return TransactionModel::global()->rowCount() > 0;
 }
 
-bool ResourcesModel::isExtended(const QString& id)
+bool ResourcesModel::isExtended(const QString &id)
 {
     bool ret = true;
-    foreach (AbstractResourcesBackend* backend, m_backends) {
+    foreach (AbstractResourcesBackend *backend, m_backends) {
         ret = backend->extends().contains(id);
         if (ret)
             break;
@@ -281,7 +294,7 @@ bool ResourcesModel::isExtended(const QString& id)
     return ret;
 }
 
-AggregatedResultsStream::AggregatedResultsStream(const QSet<ResultsStream*>& streams)
+AggregatedResultsStream::AggregatedResultsStream(const QSet<ResultsStream *> &streams)
     : ResultsStream(QStringLiteral("AggregatedResultsStream"))
 {
     Q_ASSERT(!streams.contains(nullptr));
@@ -290,7 +303,7 @@ AggregatedResultsStream::AggregatedResultsStream(const QSet<ResultsStream*>& str
         QTimer::singleShot(0, this, &AggregatedResultsStream::clear);
     }
 
-    for (auto stream: streams) {
+    for (auto stream : streams) {
         connect(stream, &ResultsStream::resourcesFound, this, &AggregatedResultsStream::addResults);
         connect(stream, &QObject::destroyed, this, &AggregatedResultsStream::streamDestruction);
         connect(this, &ResultsStream::fetchMore, stream, &ResultsStream::fetchMore);
@@ -303,9 +316,9 @@ AggregatedResultsStream::AggregatedResultsStream(const QSet<ResultsStream*>& str
 
 AggregatedResultsStream::~AggregatedResultsStream() = default;
 
-void AggregatedResultsStream::addResults(const QVector<AbstractResource *>& res)
+void AggregatedResultsStream::addResults(const QVector<AbstractResource *> &res)
 {
-    for(auto r : res)
+    for (auto r : res)
         connect(r, &QObject::destroyed, this, &AggregatedResultsStream::resourceDestruction);
 
     m_results += res;
@@ -323,12 +336,12 @@ void AggregatedResultsStream::emitResults()
     m_delayedEmission.stop();
 }
 
-void AggregatedResultsStream::resourceDestruction(QObject* obj)
+void AggregatedResultsStream::resourceDestruction(QObject *obj)
 {
-    m_results.removeAll(qobject_cast<AbstractResource*>(obj));
+    m_results.removeAll(qobject_cast<AbstractResource *>(obj));
 }
 
-void AggregatedResultsStream::streamDestruction(QObject* obj)
+void AggregatedResultsStream::streamDestruction(QObject *obj)
 {
     m_streams.remove(obj);
     clear();
@@ -343,33 +356,30 @@ void AggregatedResultsStream::clear()
     }
 }
 
-AggregatedResultsStream* ResourcesModel::search(const AbstractResourcesBackend::Filters& search)
+AggregatedResultsStream *ResourcesModel::search(const AbstractResourcesBackend::Filters &search)
 {
     if (search.isEmpty()) {
-        return new AggregatedResultsStream ({new ResultsStream(QStringLiteral("emptysearch"), {})});
+        return new AggregatedResultsStream({new ResultsStream(QStringLiteral("emptysearch"), {})});
     }
 
-    auto streams = kTransform<QSet<ResultsStream*>>(m_backends, [search](AbstractResourcesBackend* backend){ return backend->search(search); });
+    auto streams = kTransform<QSet<ResultsStream *>>(m_backends, [search](AbstractResourcesBackend *backend) {
+        return backend->search(search);
+    });
     return new AggregatedResultsStream(streams);
 }
 
 void ResourcesModel::checkForUpdates()
 {
-    for(auto backend: qAsConst(m_backends))
+    for (auto backend : qAsConst(m_backends))
         backend->checkForUpdates();
 }
 
-QVariantList ResourcesModel::backendsVariant() const
-{
-    return kTransform<QVariantList>(m_backends, [](AbstractResourcesBackend* b) {return QVariant::fromValue<QObject*>(b);});
-}
-
-AbstractResourcesBackend* ResourcesModel::currentApplicationBackend() const
+AbstractResourcesBackend *ResourcesModel::currentApplicationBackend() const
 {
     return m_currentApplicationBackend;
 }
 
-void ResourcesModel::setCurrentApplicationBackend(AbstractResourcesBackend* backend, bool write)
+void ResourcesModel::setCurrentApplicationBackend(AbstractResourcesBackend *backend, bool write)
 {
     if (backend != m_currentApplicationBackend) {
         if (write) {
@@ -390,9 +400,13 @@ void ResourcesModel::initApplicationsBackend()
 {
     const auto name = applicationSourceName();
 
-    auto idx = kIndexOf(m_backends, [name](AbstractResourcesBackend* b) { return b->hasApplications() && b->name() == name; });
-    if (idx<0) {
-        idx = kIndexOf(m_backends, [](AbstractResourcesBackend* b) { return b->hasApplications(); });
+    auto idx = kIndexOf(m_backends, [name](AbstractResourcesBackend *b) {
+        return b->hasApplications() && b->name() == name;
+    });
+    if (idx < 0) {
+        idx = kIndexOf(m_backends, [](AbstractResourcesBackend *b) {
+            return b->hasApplications();
+        });
         qCDebug(LIBDISCOVER_LOG) << "falling back applications backend to" << idx;
     }
     setCurrentApplicationBackend(m_backends.value(idx, nullptr), false);
