@@ -4,29 +4,30 @@
  *   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#include <QApplication>
-#include <KStatusNotifierItem>
-#include <QMenu>
-#include <KLocalizedString>
+#include "../DiscoverVersion.h"
 #include <KAboutData>
-#include <KCrash>
-#include <KDBusService>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KCrash>
+#include <KDBusService>
+#include <KLocalizedString>
 #include <KSharedConfig>
+#include <KStatusNotifierItem>
+#include <QApplication>
 #include <QCommandLineParser>
-#include <QDBusMessage>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
+#include <QDBusMessage>
 #include <QDebug>
-#include "../DiscoverVersion.h"
+#include <QMenu>
 
 #include "NotifierItem.h"
 
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     app.setOrganizationDomain(QStringLiteral("kde.org"));
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
     KCrash::setFlags(KCrash::AutoRestart);
 
@@ -34,20 +35,21 @@ int main(int argc, char** argv)
     bool hide = false;
     KDBusService::StartupOptions startup = {};
     {
-        KAboutData about(QStringLiteral("DiscoverNotifier"), i18n("Discover Notifier"), version, i18n("System update status notifier"),
-                     KAboutLicense::GPL, i18n("© 2010-2020 Plasma Development Team"));
+        KAboutData about(QStringLiteral("DiscoverNotifier"),
+                         i18n("Discover Notifier"),
+                         version,
+                         i18n("System update status notifier"),
+                         KAboutLicense::GPL,
+                         i18n("© 2010-2020 Plasma Development Team"));
         about.addAuthor(QStringLiteral("Aleix Pol Gonzalez"), {}, QStringLiteral("aleixpol@kde.org"));
         about.setProductName("discover/discover");
         about.setProgramLogo(app.windowIcon());
-        about.setTranslator(
-                i18ndc(nullptr, "NAME OF TRANSLATORS", "Your names"),
-                i18ndc(nullptr, "EMAIL OF TRANSLATORS", "Your emails"));
+        about.setTranslator(i18ndc(nullptr, "NAME OF TRANSLATORS", "Your names"), i18ndc(nullptr, "EMAIL OF TRANSLATORS", "Your emails"));
 
         KAboutData::setApplicationData(about);
 
         QCommandLineParser parser;
-        QCommandLineOption replaceOption({QStringLiteral("replace")},
-                                 i18n("Replace an existing instance"));
+        QCommandLineOption replaceOption({QStringLiteral("replace")}, i18n("Replace an existing instance"));
         parser.addOption(replaceOption);
         QCommandLineOption hideOption({QStringLiteral("hide")}, i18n("Do not show the notifier"), i18n("hidden"), QStringLiteral("false"));
         parser.addOption(hideOption);
